/****************************************************************************
** libebml : parse EBML files, see http://embl.sourceforge.net/
**
** <file/class description>
**
** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
**
** This file is part of libebml.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding an other license may use this file in accordance with 
** the Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.matroska.org/license/qpl/ for QPL licensing information.
** See http://www.matroska.org/license/gpl/ for GPL licensing information.
**
** Contact license@matroska.org if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

/*!
	\file
	\version \$Id: EbmlSubHead.h,v 1.7 2004/01/10 15:31:02 robux4 Exp $
	\author Steve Lhomme     <robux4 @ users.sf.net>
*/
#ifndef LIBEBML_SUBHEAD_H
#define LIBEBML_SUBHEAD_H

#include <string>

#include "EbmlUInteger.h"
#include "EbmlString.h"

START_LIBEBML_NAMESPACE

class EBML_DLL_API EVersion : public EbmlUInteger {
	public:
		EVersion() :EbmlUInteger(1) {}
		EVersion(const EVersion & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EVersion);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EVersion(*this);}
};

class EBML_DLL_API EReadVersion : public EbmlUInteger {
	public:
		EReadVersion() :EbmlUInteger(1) {}
		EReadVersion(const EReadVersion & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EReadVersion);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EReadVersion(*this);}
};

class EBML_DLL_API EMaxIdLength : public EbmlUInteger {
	public:
		EMaxIdLength() :EbmlUInteger(4) {}
		EMaxIdLength(const EMaxIdLength & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EMaxIdLength);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EMaxIdLength(*this);}
};

class EBML_DLL_API EMaxSizeLength : public EbmlUInteger {
	public:
		EMaxSizeLength() :EbmlUInteger(8) {}
		EMaxSizeLength(const EMaxSizeLength & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EMaxSizeLength);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EMaxSizeLength(*this);}
};

class EBML_DLL_API EDocType : public EbmlString {
	public:
		EDocType() {}
		EDocType(const EDocType & ElementToClone) : EbmlString(ElementToClone) {}
		static EbmlElement & Create() {return *(new EDocType);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EDocType(*this);}
};

class EBML_DLL_API EDocTypeVersion : public EbmlUInteger {
	public:
		EDocTypeVersion() {}
		EDocTypeVersion(const EDocTypeVersion & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EDocTypeVersion);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EDocTypeVersion(*this);}
};

class EBML_DLL_API EDocTypeReadVersion : public EbmlUInteger {
	public:
		EDocTypeReadVersion() {}
		EDocTypeReadVersion(const EDocTypeReadVersion & ElementToClone) : EbmlUInteger(ElementToClone) {}
		static EbmlElement & Create() {return *(new EDocTypeReadVersion);}
		const EbmlCallbacks & Generic() const {return ClassInfos;}
		static const EbmlCallbacks ClassInfos;
		operator const EbmlId &() const {return ClassInfos.GlobalId;}
		EbmlElement * Clone() const {return new EDocTypeReadVersion(*this);}
};

END_LIBEBML_NAMESPACE

#endif // LIBEBML_SUBHEAD_H
